==> Perl-Critic-Itch-0.03.tar.gz: Perl-Critic-Itch-0.03/lib/Perl/Critic/Itch.pm <==
package Perl::Critic::Itch;

use warnings;
use strict;

=head1 NAME

Perl::Critic::Itch - A collection of Policies to solve some Itches

=head1 VERSION

Version 0.03

=cut

our $VERSION = '0.03';


=head1 SYNOPSIS

Perl::Critic::Itch was created to furfill some special requests when 
analysing Perl Code. This policies, may not be usefull to everyone,
and surely not consensual, but they solve some little itches i had,
and it makes me sleep better at night!
  
List of Policies implemented:

=head2 L<Perl::Critic::Policy::CodeLayout::ProhibitHashBarewords>


=head1 AUTHOR

Marcelo Rodrigues, C<< <marcelo at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-perl-critic-itch at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Critic-Itch>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Perl::Critic::Itch


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Perl-Critic-Itch>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Perl-Critic-Itch>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Perl-Critic-Itch>

=item * Search CPAN

L<http://search.cpan.org/dist/Perl-Critic-Itch/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut

1; # End of Perl::Critic::Itch

==> Perl-Critic-Itch-0.04.tar.gz: Perl-Critic-Itch-0.04/lib/Perl/Critic/Itch.pm <==
package Perl::Critic::Itch;

use warnings;
use strict;

=head1 NAME

Perl::Critic::Itch - A collection of Perl::Critic Policies to solve some Itches

=head1 VERSION

Version 0.04

=cut

our $VERSION = '0.04';


=head1 SYNOPSIS

Perl::Critic::Itch was created to fulfill some special requests when 
analyzing Perl Code. This policies, may not be useful to everyone,
and surely not consensual, but they solve some little itches I had,
and it makes me sleep better at night!
  
List of Policies implemented:

=head2 L<Perl::Critic::Policy::CodeLayout::ProhibitHashBarewords>


=head1 AUTHOR

Marcelo Rodrigues, C<< <marcelo at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-perl-critic-itch at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Critic-Itch>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Perl::Critic::Itch


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Perl-Critic-Itch>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Perl-Critic-Itch>

=item * Search CPAN

L<http://search.cpan.org/dist/Perl-Critic-Itch/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut

1; # End of Perl::Critic::Itch
